import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const titleText = 'Selected Numbers';
const xAxisLabelText = '';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d['Property'];
  const yValue = d => d.Name;
  const margin = { top: 100, right:60, bottom: 77, left:100 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // Scales
  const xScale = scaleLinear()
    .domain([0, 4 ])
    .range([0, innerWidth]);
  
  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
    .padding(0.4);


  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // y-Axis
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)

  const yAxisG = g.append('g').call(yAxis)
   	.style("stroke-dasharray", "2 5")
    .selectAll('.domain') // .tick line
    .remove();
  

  // x-Axis
  const xAxisTickFormat = number => (number)

  const xAxis = axisBottom(xScale)
   // .tickFormat(xAxisTickFormat)
    .tickSize(-innerHeight);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 65)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabelText);
  
  // Data Points
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)) + yScale.bandwidth() / 2)
      .attr('cx', d => xScale(xValue(d)))
       .attr('r', yScale.bandwidth() / 4);
  
  // Title
  g.append('text')
      .attr('class', 'title')
      .attr('y', -30)
  		.attr('x', xScale/2)
      .text(titleText);
};

// Source
csv('data.csv').then(data => {
  data.forEach(d => {
    d.Property = +d.Property;
  });
  render(data);
});